==> istio-model-v1alpha3-6.9.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/WorkloadEntrySpecFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class WorkloadEntrySpecFluent<A extends WorkloadEntrySpecFluent<A>> extends BaseFluent<A>{
  public WorkloadEntrySpecFluent() {
  }
  
  public WorkloadEntrySpecFluent(WorkloadEntrySpec instance) {
    this.copyInstance(instance);
  }
  private String address;
  private Map<String,String> labels;
  private String locality;
  private String network;
  private Map<String,Long> ports;
  private String serviceAccount;
  private Integer weight;
  
  protected void copyInstance(WorkloadEntrySpec instance) {
    instance = (instance != null ? instance : new WorkloadEntrySpec());
  
    if (instance != null) {
        this.withAddress(instance.getAddress());
        this.withLabels(instance.getLabels());
        this.withLocality(instance.getLocality());
        this.withNetwork(instance.getNetwork());
        this.withPorts(instance.getPorts());
        this.withServiceAccount(instance.getServiceAccount());
        this.withWeight(instance.getWeight());
        this.withAddress(instance.getAddress());
        this.withLabels(instance.getLabels());
        this.withLocality(instance.getLocality());
        this.withNetwork(instance.getNetwork());
        this.withPorts(instance.getPorts());
        this.withServiceAccount(instance.getServiceAccount());
        this.withWeight(instance.getWeight());
      }
  }
  
  public String getAddress() {
    return this.address;
  }
  
  public A withAddress(String address) {
    this.address=address; return (A) this;
  }
  
  public boolean hasAddress() {
    return this.address != null;
  }
  
  public A addToLabels(String key,String value) {
    if(this.labels == null && key != null && value != null) { this.labels = new LinkedHashMap(); }
    if(key != null && value != null) {this.labels.put(key, value);} return (A)this;
  }
  
  public A addToLabels(Map<String,String> map) {
    if(this.labels == null && map != null) { this.labels = new LinkedHashMap(); }
    if(map != null) { this.labels.putAll(map);} return (A)this;
  }
  
  public A removeFromLabels(String key) {
    if(this.labels == null) { return (A) this; }
    if(key != null && this.labels != null) {this.labels.remove(key);} return (A)this;
  }
  
  public A removeFromLabels(Map<String,String> map) {
    if(this.labels == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.labels != null){this.labels.remove(key);}}} return (A)this;
  }
  
  public Map<String,String> getLabels() {
    return this.labels;
  }
  
  public <K,V>A withLabels(Map<String,String> labels) {
    if (labels == null) { this.labels =  null;} else {this.labels = new LinkedHashMap(labels);} return (A) this;
  }
  
  public boolean hasLabels() {
    return this.labels != null;
  }
  
  public String getLocality() {
    return this.locality;
  }
  
  public A withLocality(String locality) {
    this.locality=locality; return (A) this;
  }
  
  public boolean hasLocality() {
    return this.locality != null;
  }
  
  public String getNetwork() {
    return this.network;
  }
  
  public A withNetwork(String network) {
    this.network=network; return (A) this;
  }
  
  public boolean hasNetwork() {
    return this.network != null;
  }
  
  public A addToPorts(String key,Long value) {
    if(this.ports == null && key != null && value != null) { this.ports = new LinkedHashMap(); }
    if(key != null && value != null) {this.ports.put(key, value);} return (A)this;
  }
  
  public A addToPorts(Map<String,Long> map) {
    if(this.ports == null && map != null) { this.ports = new LinkedHashMap(); }
    if(map != null) { this.ports.putAll(map);} return (A)this;
  }
  
  public A removeFromPorts(String key) {
    if(this.ports == null) { return (A) this; }
    if(key != null && this.ports != null) {this.ports.remove(key);} return (A)this;
  }
  
  public A removeFromPorts(Map<String,Long> map) {
    if(this.ports == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.ports != null){this.ports.remove(key);}}} return (A)this;
  }
  
  public Map<String,Long> getPorts() {
    return this.ports;
  }
  
  public <K,V>A withPorts(Map<String,Long> ports) {
    if (ports == null) { this.ports =  null;} else {this.ports = new LinkedHashMap(ports);} return (A) this;
  }
  
  public boolean hasPorts() {
    return this.ports != null;
  }
  
  public String getServiceAccount() {
    return this.serviceAccount;
  }
  
  public A withServiceAccount(String serviceAccount) {
    this.serviceAccount=serviceAccount; return (A) this;
  }
  
  public boolean hasServiceAccount() {
    return this.serviceAccount != null;
  }
  
  public Integer getWeight() {
    return this.weight;
  }
  
  public A withWeight(Integer weight) {
    this.weight=weight; return (A) this;
  }
  
  public boolean hasWeight() {
    return this.weight != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    WorkloadEntrySpecFluent that = (WorkloadEntrySpecFluent) o;
    if (!java.util.Objects.equals(address, that.address)) return false;
  
    if (!java.util.Objects.equals(labels, that.labels)) return false;
  
    if (!java.util.Objects.equals(locality, that.locality)) return false;
  
    if (!java.util.Objects.equals(network, that.network)) return false;
  
    if (!java.util.Objects.equals(ports, that.ports)) return false;
  
    if (!java.util.Objects.equals(serviceAccount, that.serviceAccount)) return false;
  
    if (!java.util.Objects.equals(weight, that.weight)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(address,  labels,  locality,  network,  ports,  serviceAccount,  weight,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (address != null) { sb.append("address:"); sb.append(address + ","); }
    if (labels != null && !labels.isEmpty()) { sb.append("labels:"); sb.append(labels + ","); }
    if (locality != null) { sb.append("locality:"); sb.append(locality + ","); }
    if (network != null) { sb.append("network:"); sb.append(network + ","); }
    if (ports != null && !ports.isEmpty()) { sb.append("ports:"); sb.append(ports + ","); }
    if (serviceAccount != null) { sb.append("serviceAccount:"); sb.append(serviceAccount + ","); }
    if (weight != null) { sb.append("weight:"); sb.append(weight); }
    sb.append("}");
    return sb.toString();
  }
  

}

==> istio-model-v1alpha3-6.9.2-sources.jar: io/fabric8/istio/api/networking/v1alpha3/WorkloadEntrySpecFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class WorkloadEntrySpecFluent<A extends WorkloadEntrySpecFluent<A>> extends BaseFluent<A>{
  public WorkloadEntrySpecFluent() {
  }
  
  public WorkloadEntrySpecFluent(WorkloadEntrySpec instance) {
    this.copyInstance(instance);
  }
  private String address;
  private Map<String,String> labels;
  private String locality;
  private String network;
  private Map<String,Long> ports;
  private String serviceAccount;
  private Integer weight;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(WorkloadEntrySpec instance) {
    instance = (instance != null ? instance : new WorkloadEntrySpec());
    if (instance != null) {
          this.withAddress(instance.getAddress());
          this.withLabels(instance.getLabels());
          this.withLocality(instance.getLocality());
          this.withNetwork(instance.getNetwork());
          this.withPorts(instance.getPorts());
          this.withServiceAccount(instance.getServiceAccount());
          this.withWeight(instance.getWeight());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public String getAddress() {
    return this.address;
  }
  
  public A withAddress(String address) {
    this.address = address;
    return (A) this;
  }
  
  public boolean hasAddress() {
    return this.address != null;
  }
  
  public A addToLabels(String key,String value) {
    if(this.labels == null && key != null && value != null) { this.labels = new LinkedHashMap(); }
    if(key != null && value != null) {this.labels.put(key, value);} return (A)this;
  }
  
  public A addToLabels(Map<String,String> map) {
    if(this.labels == null && map != null) { this.labels = new LinkedHashMap(); }
    if(map != null) { this.labels.putAll(map);} return (A)this;
  }
  
  public A removeFromLabels(String key) {
    if(this.labels == null) { return (A) this; }
    if(key != null && this.labels != null) {this.labels.remove(key);} return (A)this;
  }
  
  public A removeFromLabels(Map<String,String> map) {
    if(this.labels == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.labels != null){this.labels.remove(key);}}} return (A)this;
  }
  
  public Map<String,String> getLabels() {
    return this.labels;
  }
  
  public <K,V>A withLabels(Map<String,String> labels) {
    if (labels == null) {
      this.labels = null;
    } else {
      this.labels = new LinkedHashMap(labels);
    }
    return (A) this;
  }
  
  public boolean hasLabels() {
    return this.labels != null;
  }
  
  public String getLocality() {
    return this.locality;
  }
  
  public A withLocality(String locality) {
    this.locality = locality;
    return (A) this;
  }
  
  public boolean hasLocality() {
    return this.locality != null;
  }
  
  public String getNetwork() {
    return this.network;
  }
  
  public A withNetwork(String network) {
    this.network = network;
    return (A) this;
  }
  
  public boolean hasNetwork() {
    return this.network != null;
  }
  
  public A addToPorts(String key,Long value) {
    if(this.ports == null && key != null && value != null) { this.ports = new LinkedHashMap(); }
    if(key != null && value != null) {this.ports.put(key, value);} return (A)this;
  }
  
  public A addToPorts(Map<String,Long> map) {
    if(this.ports == null && map != null) { this.ports = new LinkedHashMap(); }
    if(map != null) { this.ports.putAll(map);} return (A)this;
  }
  
  public A removeFromPorts(String key) {
    if(this.ports == null) { return (A) this; }
    if(key != null && this.ports != null) {this.ports.remove(key);} return (A)this;
  }
  
  public A removeFromPorts(Map<String,Long> map) {
    if(this.ports == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.ports != null){this.ports.remove(key);}}} return (A)this;
  }
  
  public Map<String,Long> getPorts() {
    return this.ports;
  }
  
  public <K,V>A withPorts(Map<String,Long> ports) {
    if (ports == null) {
      this.ports = null;
    } else {
      this.ports = new LinkedHashMap(ports);
    }
    return (A) this;
  }
  
  public boolean hasPorts() {
    return this.ports != null;
  }
  
  public String getServiceAccount() {
    return this.serviceAccount;
  }
  
  public A withServiceAccount(String serviceAccount) {
    this.serviceAccount = serviceAccount;
    return (A) this;
  }
  
  public boolean hasServiceAccount() {
    return this.serviceAccount != null;
  }
  
  public Integer getWeight() {
    return this.weight;
  }
  
  public A withWeight(Integer weight) {
    this.weight = weight;
    return (A) this;
  }
  
  public boolean hasWeight() {
    return this.weight != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    WorkloadEntrySpecFluent that = (WorkloadEntrySpecFluent) o;
    if (!java.util.Objects.equals(address, that.address)) return false;
    if (!java.util.Objects.equals(labels, that.labels)) return false;
    if (!java.util.Objects.equals(locality, that.locality)) return false;
    if (!java.util.Objects.equals(network, that.network)) return false;
    if (!java.util.Objects.equals(ports, that.ports)) return false;
    if (!java.util.Objects.equals(serviceAccount, that.serviceAccount)) return false;
    if (!java.util.Objects.equals(weight, that.weight)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(address,  labels,  locality,  network,  ports,  serviceAccount,  weight,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (address != null) { sb.append("address:"); sb.append(address + ","); }
    if (labels != null && !labels.isEmpty()) { sb.append("labels:"); sb.append(labels + ","); }
    if (locality != null) { sb.append("locality:"); sb.append(locality + ","); }
    if (network != null) { sb.append("network:"); sb.append(network + ","); }
    if (ports != null && !ports.isEmpty()) { sb.append("ports:"); sb.append(ports + ","); }
    if (serviceAccount != null) { sb.append("serviceAccount:"); sb.append(serviceAccount + ","); }
    if (weight != null) { sb.append("weight:"); sb.append(weight + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}
